@@ -27,6 +27,7 @@ import datetime
 import conf.config
 from util.trace import Trace
 from util.options import *
+from util.translate import *
 from conf.config import *
 from conf.fileconfig import *
 from conf.importconfig import *
@@ -37,8 +38,10 @@ class Config(object):
 
   cfg = 'conf/base.cfg'
   py = 'conf/config.py'
+  po = 'conf/elyxer.pot'
   addcfg = None
   importcfg = None
+  importcsv = None
   help = False
 
   def run(self, args):
@@ -52,7 +55,7 @@ class Config(object):
       self.usage()
     option = self.parseoption(args)
     if not option:
-      Trace.error('Choose cfg or py')
+      Trace.error('Choose cfg, py or po')
       self.usage()
     if option == 'cfg':
       self.exportcfg()
@@ -60,6 +63,8 @@ class Config(object):
     elif option == 'py':
       self.exportpy()
       return
+    elif option == 'po':
+      self.exportpo()
     else:
       Trace.error('Unknown option ' + option)
       self.usage()
@@ -74,6 +79,7 @@ class Config(object):
     Trace.error('    --addcfg add.cfg: load additional config file')
     Trace.error('    --py config.py: choose Python config file')
     Trace.error('    --importcfg unicodesymbols: import LyX unicode symbols file')
+    Trace.error('    --importcsv unicodecsv: import a file of "\command,unicode" pairs')
     exit()
 
   def read(self):
@@ -85,6 +91,9 @@ class Config(object):
     if Config.importcfg:
       addreader = ImportCommands(Config.importcfg).parse()
       self.mix(reader, addreader)
+    if Config.importcsv:
+      addreader = ImportCsv(Config.importcsv).parse()
+      self.mix(reader, addreader)
     reader.objects['GeneralConfig.version']['date'] = datetime.date.today().isoformat()
     return reader
 
@@ -99,9 +108,16 @@ class Config(object):
     "Export configuration as a Python file"
     reader = self.read()
     linewriter = LineWriter(Config.py)
-    translator = ConfigTranslator(linewriter)
+    translator = ConfigToPython(linewriter)
     translator.write(reader.objects)
 
+  def exportpo(self):
+    "Export configuration as a gettext .po file."
+    reader = self.read()
+    writer = LineWriter(Config.po)
+    export = TranslationExport(writer)
+    export.export(reader.objects['TranslationConfig.constants'])
+
   def parseoption(self, args):
     "Parse the next option"
     if len(args) == 0:
