@@ -42,10 +42,12 @@ class Link(Container):
     self.type = None
     self.page = None
     self.target = None
+    self.destination = None
+    self.title = None
     if Options.target:
       self.target = Options.target
 
-  def complete(self, text, anchor = None, url = None, type = None):
+  def complete(self, text, anchor = None, url = None, type = None, title = None):
     "Complete the link."
     self.contents = [Constant(text)]
     if anchor:
@@ -54,22 +56,25 @@ class Link(Container):
       self.url = url
     if type:
       self.type = type
+    if title:
+      self.title = title
     return self
 
-  def setdestination(self, destination):
-    "Set another link as the destination of this one."
-    self.destination = destination
-    if not destination.anchor:
-      Trace.error('Missing anchor in link destination ' + unicode(destination))
+  def computedestination(self):
+    "Use the destination link to fill in the destination URL."
+    if not self.destination:
       return
-    self.url = '#' + destination.anchor
-    if destination.page:
-      self.url = destination.page + self.url
+    if not self.destination.anchor:
+      Trace.error('Missing anchor in link destination ' + unicode(self.destination))
+      return
+    self.url = '#' + self.destination.anchor
+    if self.destination.page:
+      self.url = self.destination.page + self.url
 
   def setmutualdestination(self, destination):
     "Set another link as destination, and set its destination to this one."
-    self.setdestination(destination)
-    destination.setdestination(self)
+    self.destination = destination
+    destination.destination = self
 
 class ListInset(Container):
   "An inset with a list, normally made of links."
@@ -91,7 +96,7 @@ class ListOf(ListInset):
   def process(self):
     "Parse the header and get the type"
     self.type = self.header[2]
-    text = TranslationConfig.lists[self.type]
+    text = Translator.translate('list-' + self.type)
     self.contents = [TaggedText().constant(text, 'div class="tocheader"', True)]
 
 class TableOfContents(ListInset):
@@ -99,7 +104,7 @@ class TableOfContents(ListInset):
 
   def process(self):
     "Parse the header and get the type"
-    text = TranslationConfig.constants['toc']
+    text = Translator.translate('toc')
     self.contents = [TaggedText().constant(text, 'div class="tocheader"', True)]
 
 class IndexEntry(Link):
@@ -129,9 +134,9 @@ class IndexEntry(Link):
       IndexEntry.arrows[key] = []
     self.index = len(IndexEntry.arrows[key])
     self.complete(u'↓', 'entry-' + key + '-' + unicode(self.index))
-    self.setdestination(IndexEntry.entries[key])
+    self.destination = IndexEntry.entries[key]
     arrow = Link().complete(u'↑', 'index-' + key)
-    arrow.setdestination(self)
+    arrow.destination = self
     IndexEntry.arrows[key].append(arrow)
 
 class PrintIndex(ListInset):
@@ -139,7 +144,7 @@ class PrintIndex(ListInset):
 
   def process(self):
     "Create the alphabetic index"
-    index = TranslationConfig.constants['index']
+    index = Translator.translate('index')
     self.contents = [TaggedText().constant(index, 'h1 class="index"'),
         Constant('\n')]
     for key in self.sortdictionary(IndexEntry.entries):
@@ -180,7 +185,7 @@ class PrintNomenclature(ListInset):
   "Print all nomenclature entries"
 
   def process(self):
-    nomenclature = TranslationConfig.constants['nomenclature']
+    nomenclature = Translator.translate('nomenclature')
     self.contents = [TaggedText().constant(nomenclature,
       'h1 class="nomenclature"')]
     for key in self.sortdictionary(NomenclatureEntry.entries):
@@ -214,18 +219,22 @@ class LinkOutput(object):
   "A link pointing to some destination"
   "Or an anchor (destination)"
 
-  def gethtml(self, container):
+  def gethtml(self, link):
     "Get the HTML code for the link"
-    type = container.__class__.__name__
-    if container.type:
-      type = container.type
+    type = link.__class__.__name__
+    if link.type:
+      type = link.type
     tag = 'a class="' + type + '"'
-    if container.anchor:
-      tag += ' name="' + container.anchor + '"'
-    if container.url:
-      tag += ' href="' + container.url + '"'
-    if container.target:
-      tag += ' target="' + container.target + '"'
-    text = TaggedText().complete(container.contents, tag)
+    if link.anchor:
+      tag += ' name="' + link.anchor + '"'
+    if link.destination:
+      link.computedestination()
+    if link.url:
+      tag += ' href="' + link.url + '"'
+    if link.target:
+      tag += ' target="' + link.target + '"'
+    if link.title:
+      tag += ' title="' + link.title + '"'
+    text = TaggedText().complete(link.contents, tag)
     return text.gethtml()
 
